#
# spec file for package xwininfo
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xwininfo
Version:        1.1.6
Release:        1.6
Summary:        Window information utility for X
License:        MIT
Group:          System/X11/Utilities
URL:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb) >= 1.6
BuildRequires:  pkgconfig(xcb-shape)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
xwininfo prints information about windows on an X server.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%doc ChangeLog COPYING README.md
%{_bindir}/xwininfo
%{_mandir}/man1/xwininfo.1%{?ext_man}

%changelog
* Mon Apr 10 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.6
  * This release adds an option, disabled by default, to use libxcb-errors to
    improve the reporting of any X protocol error messages that may occur.
    To enable it, pass --with-xcb-errors to configure.
* Mon Jul 15 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.5
  * Clear -Wsign-compare warnings from gcc 7.3
  * In Find_Client, if (win == XCB_WINDOW_NONE), roots should be freed.
  * Update configure.ac bug URL for gitlab migration
  * Improve manpage and -h option
  * Update README for gitlab migration
* Thu Apr  5 2018 sndirsch@suse.com
- Update to version 1.1.4
  * autogen.sh changes
  * configure: Drop AM_MAINTAINER_MODE
  * Print which option was in error along with usage message
  * Add -version option to print program version
  * xwininfo: do not segfault on IO error
* Mon May 20 2013 zaitor@opensuse.org
- Update to version 1.1.3:
  + Quiet some clang warnings about implicit int <-> size_t
    conversions.
  + xwininfo: report the Visual class of the selected Window.
  + Print more detailed error messages when xcb_connect fails.
  + fdo#53242 - xwininfo segfaults on invalid screen.
  + Get rid of a number of warnings.
  + Remove dead code (size_t is always >= 0).
  + configure.ac: regroup statements and comment.
  + Use format string literals instead of variables to print atom
    names.
  + Refactor atom name printing into a new Display_Atom_Name
    function.
  + Use format string literals instead of variables to print window
    ids.
  + Move leading ": " out from buffer to the error string printer.
  + Add const attributes to fix gcc -Wwrite-strings warnings.
  + Strip trailing whitespace.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.1.2:
  + When matching window names, ensure name lengths match too
  + Fix for invalid free if window has a _NET_WM_NAME property
  + Update to xcb-icccm 0.3.8 API (Disabled by default)
  + Build fixes.
  + Man page fixes.
  + Build system fixes.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xwininfo from xorg-x11. Initial version: 1.1.1.
